aboutsummaryrefslogtreecommitdiffstats
path: root/target/linux/generic/files/fs/yaffs2/yaffs_linux.h
diff options
context:
space:
mode:
Diffstat (limited to 'target/linux/generic/files/fs/yaffs2/yaffs_linux.h')
-rw-r--r--target/linux/generic/files/fs/yaffs2/yaffs_linux.h35
1 files changed, 20 insertions, 15 deletions
diff --git a/target/linux/generic/files/fs/yaffs2/yaffs_linux.h b/target/linux/generic/files/fs/yaffs2/yaffs_linux.h
index 19d7b824c5..c20ab14b7f 100644
--- a/target/linux/generic/files/fs/yaffs2/yaffs_linux.h
+++ b/target/linux/generic/files/fs/yaffs2/yaffs_linux.h
@@ -1,7 +1,7 @@
/*
* YAFFS: Yet another Flash File System . A NAND-flash specific file system.
*
- * Copyright (C) 2002-2010 Aleph One Ltd.
+ * Copyright (C) 2002-2011 Aleph One Ltd.
* for Toby Churchill Ltd and Brightstar Engineering
*
* Created by Charles Manning <charles@aleph1.co.uk>
@@ -16,28 +16,33 @@
#ifndef __YAFFS_LINUX_H__
#define __YAFFS_LINUX_H__
-#include "devextras.h"
#include "yportenv.h"
-struct yaffs_LinuxContext {
- struct ylist_head contextList; /* List of these we have mounted */
- struct yaffs_dev_s *dev;
- struct super_block * superBlock;
- struct task_struct *bgThread; /* Background thread for this device */
- int bgRunning;
- struct semaphore grossLock; /* Gross locking semaphore */
- __u8 *spareBuffer; /* For mtdif2 use. Don't know the size of the buffer
+struct yaffs_linux_context {
+ struct list_head context_list; /* List of these we have mounted */
+ struct yaffs_dev *dev;
+ struct super_block *super;
+ struct task_struct *bg_thread; /* Background thread for this device */
+ int bg_running;
+ struct mutex gross_lock; /* Gross locking mutex*/
+ u8 *spare_buffer; /* For mtdif2 use. Don't know the buffer size
* at compile time so we have to allocate it.
*/
- struct ylist_head searchContexts;
- void (*putSuperFunc)(struct super_block *sb);
-
- struct task_struct *readdirProcess;
+ struct list_head search_contexts;
+ struct task_struct *readdir_process;
unsigned mount_id;
+ int dirty;
};
-#define yaffs_dev_to_lc(dev) ((struct yaffs_LinuxContext *)((dev)->os_context))
+#define yaffs_dev_to_lc(dev) ((struct yaffs_linux_context *)((dev)->os_context))
#define yaffs_dev_to_mtd(dev) ((struct mtd_info *)((dev)->driver_context))
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(2, 6, 17))
+#define WRITE_SIZE_STR "writesize"
+#define WRITE_SIZE(mtd) ((mtd)->writesize)
+#else
+#define WRITE_SIZE_STR "oobblock"
+#define WRITE_SIZE(mtd) ((mtd)->oobblock)
#endif
+#endif